@@ -6,8 +6,8 @@
 ;; Homepage: https://github.com/emacscollective/no-littering
 ;; Keywords: convenience
 
-;; Package-Version: 1.7.6
-;; Package-Requires: ((emacs "26.1") (compat "30.0.1.0"))
+;; Package-Version: 1.7.9
+;; Package-Requires: ((emacs "26.1") (compat "30.1"))
 
 ;; SPDX-License-Identifier: GPL-3.0-or-later
 
@@ -134,6 +134,8 @@ This variable has to be set before `no-littering' is loaded.")
     (setq erc-log-channels-directory       (var "erc/log-channels/"))
     (setq erc-startup-file-list            (list (etc "erc/startup.el") (etc "erc/startup") ".ercrc.el" ".ercrc"))
     (setq eshell-aliases-file              (etc "eshell/aliases"))
+    ;; This controls where `eshell-history-file-name' is places.
+    ;; Other files belong in "etc/" so theme their variables directly.
     (setq eshell-directory-name            (var "eshell/"))
     (setq eshell-login-script              (etc "eshell/login"))
     (setq eshell-rc-script                 (etc "eshell/rc"))
@@ -172,6 +174,7 @@ This variable has to be set before `no-littering' is loaded.")
     (setq save-place-file                  (var "save-place.el"))
     (setq savehist-file                    (var "savehist.el"))
     (setq semanticdb-default-save-directory (var "semantic/"))
+    (setq server-auth-dir                  (var "server/auth/"))
     (setq shadow-info-file                 (var "shadow/info.el"))
     (setq shadow-todo-file                 (var "shadow/todo.el"))
     (setq shared-game-score-directory      (var "shared-game-score/"))
@@ -187,7 +190,8 @@ This variable has to be set before `no-littering' is loaded.")
 
     (eval-after-load 'desktop     '(make-directory desktop-dirname t))
     (eval-after-load 'erc         '(make-directory erc-dcc-get-default-directory t))
-    (eval-after-load 'eshell      '(make-directory eshell-directory-name t))
+    (eval-after-load 'eshell      `(with-file-modes #o700
+                                     (make-directory ,(etc "eshell/") t)))
     (eval-after-load 'eww         '(make-directory eww-bookmarks-directory t))
     (eval-after-load 'gnus        `(make-directory ,(etc "gnus/") t))
     (eval-after-load 'gnus        '(make-directory gnus-dribble-directory t))
@@ -315,6 +319,7 @@ This variable has to be set before `no-littering' is loaded.")
     (setq org-roam-db-location             (var "org/org-roam.db"))
     (setq package-quickstart-file          (var "package-quickstart.el"))
     (setq pandoc-data-dir                  (etc "pandoc-mode/"))
+    (setq parinfer-rust-library-directory  (var "parinfer-rust/"))
     (setq pcache-directory                 (var "pcache/"))
     (setq pdf-view-restore-filename        (var "pdf-view-restore.el"))
     (setq persist--directory-location      (var "persist/"))
